OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Előnézet betöltése…",
    "Admin" : "Rendszergazda",
    "Saved" : "Mentve",
    "a safe home for all your data" : "biztonságos hely az adatai számára",
    "Error uploading the file" : "Hiba a fájl feltöltése során",
    "Name cannot be empty" : "A név nem lehet üres",
    "The given name is too long" : "A megadott név túl hosszú",
    "The given web address is too long" : "A megadott webcím túl hosszú",
    "The given web address is not a valid URL" : "A megadott webcím URL címe érvénytelen",
    "The given legal notice address is too long" : "A megadott jogi nyilatkozat címe túl hosszú",
    "The given legal notice address is not a valid URL" : "A megadott jogi nyilatkozat URL címe érvénytelen",
    "The given privacy policy address is too long" : "A megadott adatvédelmi irányelvek címe túl hosszú",
    "The given privacy policy address is not a valid URL" : "A megadott adatvédelmi irányelvek URL címe érvénytelen",
    "The given slogan is too long" : "A megadott szlogen túl hosszú",
    "The given color is invalid" : "A megadott szín érvénytelen",
    "The file was uploaded" : "A fájl fel lett töltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini upload_max_filesize direktívájában meghatározott méretet.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívájában meghatározott méretet.",
    "The file was only partially uploaded" : "A fájl csak részlegesen lett feltöltve",
    "No file was uploaded" : "Nincs feltöltött fájl",
    "Missing a temporary folder" : "Átmeneti mappa hiányzik",
    "Could not write file to disk" : "A fájlt nem sikerült a lemezre írni",
    "A PHP extension stopped the file upload" : "Egy PHP kiterjesztés megállította a fájl feltöltését",
    "No file uploaded" : "Nincs fájl feltöltve",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Már egyéni témát használ. Lehet, hogy a témázó alkalmazás beállításai felülírták.",
    "Theming" : "Témázás",
    "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
    "Dark theme with high contrast mode" : "Sötét téma magas kontrasztú móddal",
    "Enable dark high contrast mode" : "Sötét, magas kontrasztú mód engedélyezése",
    "Similar to the high contrast mode, but with dark colours." : "Hasonló a magas kontrasztú módhoz, de sötét színekkel.",
    "Dark theme" : "Sötét téma",
    "Enable dark theme" : "Sötét téma engedélyezése",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Egy szemkímélő sötét téma, amely csökkenti az átlagos fényességet és fényerőt.",
    "System default theme" : "Rendszer alapértelmezett témája",
    "Enable the system default" : "Rendszer alapértelmezésének engedélyezése",
    "Using the default system appearance." : "Az alapértelmezett rendszermegjelenés használata.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "Enable dyslexia font" : "Diszlexia betűkészlet engedélyezése",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "High contrast mode" : "Magas kontrasztú mód",
    "Enable high contrast mode" : "Magas kontrasztú mód engedélyezése",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "Light theme" : "Világos téma",
    "Enable the default light theme" : "Alapértelmezett világos téma engedélyezése",
    "The default light appearance." : "Az alapértelmezett világos megjelenés.",
    "Legal notice" : "Jogi nyilatkozat",
    "Privacy policy" : "Adatvédelmi irányelvek",
    "Adjust the Nextcloud theme" : "A Nextcloud téma módosítása",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Az akadálymentesítés fontos számunka. A webes szabványokat követjük, és ellenőrizzük, hogy minden használható egér nélkül, illetve akadálymentesítési technológiákkal, például képernyőolvasókkal. Arra törekszünk, hogy a {guidelines}Webes tartalomra vonatkozó akadálymentesítési irányelvek{linkend} 2.1-es változatának AA szinten, a magas kontrasztú témával pedig AAA szinten megfeleljünk.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!",
    "Theme selection is enforced" : "A témaválasztás kényszerített",
    "Open documentation" : "Dokumentáció megnyitása",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A témák lehetővé teszik, hogy könnyedén személyre szabja a példány és a támogatott kliensek megjelenését. Ez minden felhasználó számára látható lesz.",
    "Name" : "Név",
    "Reset to default" : "Visszaállítás alapértelmezettre",
    "Web link" : "Webes hivatkozás",
    "https://…" : "https://…",
    "Slogan" : "Szlogen",
    "Color" : "Szín",
    "Logo" : "Logó",
    "Upload new logo" : "Új logó feltöltése",
    "Login image" : "Bejelentkező kép",
    "Upload new login background" : "Új bejelentkező kép feltöltése",
    "Remove background image" : "Háttérkép eltávolítása",
    "Advanced options" : "Speciális beállítások",
    "Legal notice link" : "Jogi nyilatkozat hivatkozása",
    "Privacy policy link" : "Adatvédelmi irányelvek hivatkozása",
    "Header logo" : "Fejléc logó",
    "Upload new header logo" : "Fejléc logó feltöltése",
    "Favicon" : "Kedvencek ikon",
    "Upload new favicon" : "Kedvencek ikon feltöltése",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Telepítse az Imagemagick PHP kiterjesztést SVG képtámogatással, hogy automatikusan előállítsa a kedvencek ikont a feltöltött logó és szín alapján."
},
"nplurals=2; plural=(n != 1);");
